============
Installation
============

At the command line::

    $ easy_install xapo_sdk

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv xapo_sdk
    $ pip install xapo_sdk

Installing from the sources::

    $ ./setup.py install
